@@ -2,28 +2,44 @@ from typing import Iterator
 from typing import (Optional, Union, List, Tuple, Mapping)
 
 from tsl.utils.python_utils import ensure_list
-from .utils import SynchMode
+from .synch_mode import SynchMode, WINDOW, STATIC
 
 
 class BatchMapItem:
     def __init__(self, keys: Union[List, str],
-                 synch_mode: SynchMode = SynchMode.WINDOW,
+                 synch_mode: Optional[Union[SynchMode, str]] = None,
                  preprocess: bool = True,
                  cat_dim: Optional[int] = -1,
-                 n_channels: Optional[int] = None):
+                 pattern: Optional[str] = None,
+                 shape: Optional[tuple] = None):
         super(BatchMapItem, self).__init__()
+        # store keys to be mapped
         self.keys = ensure_list(keys)
-        assert isinstance(synch_mode, SynchMode)
-        self.synch_mode = synch_mode
-        self.preprocess = preprocess
-        if len(self.keys) > 1:
-            assert cat_dim is not None, \
-                '"cat_dim" cannot be None with multiple keys.'
+
+        # store cat_dim, i.e., the dimension along which keys must be
+        # concatenated
+        if len(self.keys) > 1 and cat_dim is None:
+            raise RuntimeError("'cat_dim' cannot be None with multiple keys.")
         self.cat_dim = cat_dim
-        self.n_channels = n_channels
+
+        # store synch_mode, i.e., where to put (sliced) data in the batch
+        if isinstance(synch_mode, str):
+            synch_mode = getattr(SynchMode, synch_mode.upper())
+        self.synch_mode = synch_mode
+
+        self.preprocess = preprocess
+        self.pattern = pattern
+        self.shape = None if shape is None else tuple(shape)
+
+    def __setattr__(self, key, value):
+        super(BatchMapItem, self).__setattr__(key, value)
+        if key == 'pattern' and value is not None and self.synch_mode is None:
+            synch_mode = WINDOW if 't' in value else STATIC
+            super(BatchMapItem, self).__setattr__('synch_mode', synch_mode)
 
     def __repr__(self):
-        return "([{}], {})".format(', '.join(self.keys), self.synch_mode.name)
+        return "([{}], pattern='{}', shape={})".format(
+            ', '.join(self.keys), self.pattern, self.shape)
 
     def kwargs(self):
         return self.__dict__
@@ -61,9 +77,8 @@ class BatchMap(Mapping):
         return iter(self.__dict__)
 
     def __repr__(self):
-        s = ['({}={}, {})'.format(key, value.keys, value.synch_mode.name)
-             for key, value in self.items()]
-        return "{}[{}]".format(self.__class__.__name__, ', '.join(s))
+        s = ["'{}': {}".format(key, repr(value)) for key, value in self.items()]
+        return "{}(\n  {}\n)".format(self.__class__.__name__, ',\n  '.join(s))
 
     def update(self, **kwargs):
         for k, v in kwargs.items():
