@@ -465,6 +465,9 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
                                             pattern='t n f',
                                             shape=self.shape)
 
+    def reset_auxiliary(self):
+        self._clear_batch_map('auxiliary')
+
     def set_input_map(self, input_map=None, **kwargs):
         self._clear_batch_map('input')
         self.update_input_map(input_map, **kwargs)
@@ -473,12 +476,19 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
         self._clear_batch_map('target')
         self.update_target_map(target_map, **kwargs)
 
+    def set_auxiliary_map(self, auxiliary_map=None, **kwargs):
+        self._clear_batch_map('auxiliary')
+        self.update_auxiliary_map(auxiliary_map, **kwargs)
+
     def update_input_map(self, input_map=None, **kwargs):
         self._update_batch_map('input', input_map, **kwargs)
 
     def update_target_map(self, target_map=None, **kwargs):
         self._update_batch_map('target', target_map, **kwargs)
 
+    def update_auxiliary_map(self, auxiliary_map=None, **kwargs):
+        self._update_batch_map('auxiliary', auxiliary_map, **kwargs)
+
     def _clear_batch_map(self, endpoint):
         batch_map = getattr(self, f"{endpoint}_map")
         for key in batch_map:
@@ -637,7 +647,7 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
 
         # get scaler (if any)
         scaler = None
-        if key in self._batch_scalers is not None:
+        if key in self._batch_scalers:
             scaler = self._batch_scalers[key].slice(time_index=time_index,
                                                     node_index=node_index)
             if itm.preprocess:  # transform tensor
@@ -769,7 +779,8 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
                       pattern: Optional[str] = None,
                       add_to_input_map: bool = True,
                       synch_mode: Optional[SynchMode] = None,
-                      preprocess: bool = True):
+                      preprocess: bool = True,
+                      convert_precision: bool = True):
         r"""Add covariate to the dataset. Examples of covariate are
         exogenous signals (in the form of dynamic multidimensional data) or
         static attributes (e.g., graph/node metadata). Parameter :obj:`pattern`
@@ -808,10 +819,14 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
             preprocess (bool): If :obj:`True` and the dataset has a scaler with
                 same key, then data are scaled when calling :obj:`get` methods.
                 (default: :obj:`True`)
+            convert_precision (bool): If :obj:`True`, then cast :attr:`value`
+                with dataset's precision.
+                (default: :obj:`True`)
         """
         # validate name. name cannot be an attribute of self, but allow override
         self._check_name(name)
-        value, pattern = self._parse_covariate(value, pattern, name=name)
+        value, pattern = self._parse_covariate(
+            value, pattern, name=name, convert_precision=convert_precision)
         self._covariates[name] = dict(value=value, pattern=pattern)
         if add_to_input_map:
             self.input_map[name] = BatchMapItem(name, synch_mode, preprocess,
@@ -991,14 +1006,22 @@ class SpatioTemporalDataset(Dataset, DataParsingMixin):
         scaler = ScalerModule(scaler)
         pattern = self.patterns[key]
         self._check_pattern(scaler.bias, pattern,
-                            name=f"{key} (scaler)", allow_broadcasting=True)
+                            name=f"scaler ({key})", allow_broadcasting=True)
         self._check_pattern(scaler.scale, pattern,
-                            name=f"{key} (scaler)", allow_broadcasting=True)
+                            name=f"scaler ({key})", allow_broadcasting=True)
         if key == 'target' and self.trend is not None:
             self.__target_bias = scaler.bias
             scaler.bias = scaler.bias + self.trend
         scaler.pattern = pattern
         self.scalers[key] = scaler
+        # cache batch scaler if target tensor is in a multi-key batch item
+        for bm in [self.input_map, self.target_map, self.auxiliary_map]:
+            for bm_key, bm_item in bm.items():
+                if key in bm_item.keys and len(bm_item.keys) > 1:
+                    tensor, scaler = self.collate_keys(bm_item.keys,
+                                                       cat_dim=bm_item.cat_dim,
+                                                       return_pattern=False)
+                    self._batch_scalers[bm_key] = scaler
 
     # Dataset trimming ########################################################
 
