@@ -3,11 +3,12 @@ from .dcrnn import DCRNNCell, DCRNN
 from .dense_dcrnn import DenseDCRNNCell, DenseDCRNN
 from .gcgru import GraphConvGRUCell, GraphConvGRU
 from .gclstm import GraphConvLSTMCell, GraphConvLSTM
-from .mlp import MLP, ResidualMLP
-from .rnn import RNN
+from .mlp import MLP, ResidualMLP, MultiMLP
+from .rnn import RNN, MultiRNN
 from .stcn import SpatioTemporalConvNet
 from .tcn import TemporalConvNet
-from .transformer import (TransformerLayer, SpatioTemporalTransformerLayer,
+from .transformer import (TransformerLayer,
+                          SpatioTemporalTransformerLayer,
                           Transformer)
 
 from .evolvegcn import EvolveGCNOCell, EvolveGCNHCell, EvolveGCN
@@ -18,7 +19,9 @@ general_classes = [
     'ConditionalTCNBlock',
     'MLP',
     'ResidualMLP',
+    'MultiMLP',
     'RNN',
+    'MultiRNN'
 ]
 
 cell_classes = [
