@@ -1,4 +1,4 @@
-from typing import Union, Tuple, List, Optional, Literal, Type
+from typing import Union, Tuple, List, Optional, Literal, Type, Dict
 
 from numpy import ndarray
 from pandas import DatetimeIndex, PeriodIndex, TimedeltaIndex, DataFrame
@@ -29,4 +29,4 @@ IndexSlice = Union[slice, Index]
 FillOptions = Optional[Literal["backfill", "bfill", "ffill", "pad",
                                "mean", "linear"]]
 
-ModelReturnOptions = Union[Type[Tensor], Type[dict], Type[list]]
+ModelReturnOptions = Type[Union[Tensor, Dict, List, Tuple]]
